==> kubernetes-model-gatewayapi-6.2.0-sources.jar: io/fabric8/kubernetes/api/model/gatewayapi/v1beta1/HTTPURLRewriteFilterFluent.java <==
package io.fabric8.kubernetes.api.model.gatewayapi.v1beta1;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public interface HTTPURLRewriteFilterFluent<A extends HTTPURLRewriteFilterFluent<A>> extends Fluent<A>{
  public String getHostname();
  public A withHostname(String hostname);
  public Boolean hasHostname();
  
  /**
   * This method has been deprecated, please use method buildPath instead.
   * @return The buildable object.
   */
  @Deprecated
  public HTTPPathModifier getPath();
  public HTTPPathModifier buildPath();
  public A withPath(HTTPPathModifier path);
  public Boolean hasPath();
  public A withNewPath(String replaceFullPath,String replacePrefixMatch,String type);
  public HTTPURLRewriteFilterFluent.PathNested<A> withNewPath();
  public HTTPURLRewriteFilterFluent.PathNested<A> withNewPathLike(HTTPPathModifier item);
  public HTTPURLRewriteFilterFluent.PathNested<A> editPath();
  public HTTPURLRewriteFilterFluent.PathNested<A> editOrNewPath();
  public HTTPURLRewriteFilterFluent.PathNested<A> editOrNewPathLike(HTTPPathModifier item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface PathNested<N> extends Nested<N>,HTTPPathModifierFluent<HTTPURLRewriteFilterFluent.PathNested<N>>{
    public N and();
    public N endPath();
    
  }
  
}

==> kubernetes-model-gatewayapi-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/gatewayapi/v1beta1/HTTPURLRewriteFilterFluent.java <==
package io.fabric8.kubernetes.api.model.gatewayapi.v1beta1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface HTTPURLRewriteFilterFluent<A extends HTTPURLRewriteFilterFluent<A>> extends Fluent<A>{
  public String getHostname();
  public A withHostname(String hostname);
  public Boolean hasHostname();
  
  /**
   * This method has been deprecated, please use method buildPath instead.
   * @return The buildable object.
   */
  @Deprecated
  public HTTPPathModifier getPath();
  public HTTPPathModifier buildPath();
  public A withPath(HTTPPathModifier path);
  public Boolean hasPath();
  public A withNewPath(String replaceFullPath,String replacePrefixMatch,String type);
  public HTTPURLRewriteFilterFluent.PathNested<A> withNewPath();
  public HTTPURLRewriteFilterFluent.PathNested<A> withNewPathLike(HTTPPathModifier item);
  public HTTPURLRewriteFilterFluent.PathNested<A> editPath();
  public HTTPURLRewriteFilterFluent.PathNested<A> editOrNewPath();
  public HTTPURLRewriteFilterFluent.PathNested<A> editOrNewPathLike(HTTPPathModifier item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface PathNested<N> extends Nested<N>,HTTPPathModifierFluent<HTTPURLRewriteFilterFluent.PathNested<N>>{
    public N and();
    public N endPath();
    
  }
  
}
